# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/project_managers/project_manager/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/project_managers/project_manager/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "ProjectManagers\\ProjectManager\\": "packages/project_managers/project_manager/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        ProjectManagers\ProjectManager\Providers\ProjectManagerServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'ProjectManager'  => ProjectManagers\ProjectManager\Facades\ProjectManager::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=ProjectManagers\\ProjectManagerTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="ProjectManagers\ProjectManager\Providers\ProjectManagerServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="ProjectManagers\ProjectManager\Providers\ProjectManagerServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="ProjectManagers\ProjectManager\Providers\ProjectManagerServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/project_manager/{modulename}

**User**

    http://path-to-route-folder/user/project_manager/{modulename}

**Public**

    http://path-to-route-folder/project_managers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/project_manager/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/project_manager/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/project_manager/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/project_manager/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/project_manager/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/project_manager/{modulename}/{slug}
    METHOD: GET